==> nextcloud-31.0.9.tgz: nextcloud/apps/circles/l10n/bg.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Вие изтрихте {circle}",
    "{author} deleted {circle}" : "{author} изтри {circle}",
    "You removed {member} from {circle}" : "Премахнахте {member} от {circle}",
    "You joined {circle}" : "Вие се присъединихте към {circle}",
    "{member} joined {circle}" : "{member} се присъедини към {circle}",
    "You accepted the invitation to join {circle}" : "Приехте поканата да се присъедините към {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} прие поканата да се присъедини към {circle}",
    "You added {member} as member to {circle}" : "Вие добавихте {member} като член на {circle}",
    "You have been added as member to {circle} by {author}" : "Бяхте добавен като член в {circle} от {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} беше добавен като член в {circle} от {author}",
    "You added {external} to {circle}" : " Добавихте {external} към {circle}",
    "{external} has been added to {circle} by {author}" : "{external} беше добавен към {circle} от {author}",
    "You accepted {member}'s request to join {circle}" : "Приехте молбата на {member} да се присъедини към {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Заявката ви за присъединяване към {circle} беше приета от {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Заявката на {member} да се присъедини към {circle} беше приета от {author}",
    "You left {circle}" : "Вие напуснахте {circle}",
    "{member} left {circle}" : "{member} напусна {circle}",
    "You declined the invitation to join {circle}" : "Отказахте поканата да се присъедините към {circle}",
    "{member} declined an invitation to join {circle}" : "{member} отказа поканата да се присъедини към  {circle}",
    "You cancelled your request to join {circle}" : "Отменихте заявката си за присъединяване към {circle}",
    "You have been removed from {circle} by {author}" : "Бяхте премахнат от {circle} от {author}",
    "{member} has been removed from {circle} by {author}" : "{member} беше премахнат от {circle} от {author}",
    "You removed {external} from {circle}" : "Вие премахнахте {external} от {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} беше премахнат от {circle} от {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Отменихте поканата на {member} да се присъедини към {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Вашата покана за присъединяване към {circle} беше отменена от {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} отмени поканата на {member} да се присъедини към {circle}",
    "You dismissed {member}'s request to join {circle}" : "Отхвърлихте молбата на {member} за присъединяване към {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Заявката ви за присъединяване към {circle} беше отхвърлена от {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Заявката на {member} да се присъедини към {кръг} беше отхвърлена от {author}",
    "You invited {member} to join {circle}" : "Поканихте {member} да се присъедини към {circle}",
    "You have been invited to join {circle} by {author}" : " Бяхте поканен да се присъедините към {circle} от {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} беше поканен да се присъедини към {circle} от {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Променихте нивото на {member} в {circle} на %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} промени вашето ниво в {circle} на %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} промени нивото на {member} в {circle} на %1$s ",
    "You sent a request to join {circle}" : "Изпратили сте заявка за присъединяване към {circle}",
    "{member} sent a request to join {circle}" : "{member} изпрати заявка за присъединяване към {circle}",
    "You are the new owner of {circle}" : "Вие сте новият собственик на {circle}",
    "{member} is the new owner of {circle}" : "{member} е новият собственик на {circle}",
    "Single" : "Единичен",
    "Personal" : "Лични",
    "System" : "Система",
    "Visible" : "Видимо",
    "Open" : "Отвори",
    "Invite" : "Покани",
    "Friends" : "Приятели",
    "Password protected" : "Защитено с парола",
    "No Owner" : "Няма собственик",
    "Hidden" : "Скрит",
    "Backend" : " Сървър",
    "Local" : "Локален",
    "Root" : "Основен",
    "Federated" : "Федериран",
    "Mount point" : "Точка на монтиране",
    "Nextcloud Account" : "Nextcloud профил",
    "Nextcloud Group" : "Nextcloud Група",
    "Email address" : "Имейл адрес",
    "Contact" : "Контакт",
    "Nextcloud App" : "Приложение Nextcloud App",
    "Member" : "Член",
    "Moderator" : "Модератор",
    "Admin" : "Администратор",
    "Owner" : "Създател",
    "%s shared »%s« with you." : "%s сподели »%s« с вас.",
    "%s shared »%s« with \"%s\"." : "%s сподели »%s« с „%s“.",
    "%s on %s" : "%s на %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$sсподели »%2$s« с вас. Вече трябва да сте получили отделен имейл с връзка за достъп до него.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s сподели %2$s с вас. Вече трябва да сте получили отделен имейл с връзка за достъп до него.",
    "Password to access »%1$s« shared to you by %2$s" : "Парола за достъп »%1$s» е споделенас вас от %2$s",
    "Password to access »%s«" : "Парола за достъп »%s»",
    "It is protected with the following password:" : "Защитен е със следната парола:",
    "%1$s via %2$s" : "%1$sчрез %2$s ",
    "Click the button below to open it." : "Щракнете върху бутона по-долу, за да го отворите.",
    "Open »%s«" : "Отвори »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s сподели множество файла с вас. Вече трябва да сте получили отделен имейл с връзка за достъп до тях.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$sсподели множество файлове с вас. Вече трябва да сте получили отделна поща с връзка за достъп до тях. ",
    "Password to access files shared to you by %1$s" : "Парола за достъп до файлове, споделени с вас от %1$s",
    "Password to access files" : "Парола за достъп до файлове",
    "%s shared multiple files with \"%s\"." : "%s сподели множество файла с „%s“.",
    "%s shared multiple files with you." : "%sсподелени множество файлове с вас",
    "Boot up" : "Стартиране",
    "Nextcloud Initialization" : "Инициализация на Nextcloud",
    "Circles App Initialization" : "Инициализация на приложението Circles /кръгове/",
    "Fresh installation status" : "Състояние на нова инсталация",
    "Building Local Database" : "Изграждане на Локална База Данни",
    "Testing Basic Circle Creation" : "Тестване на създаването на основен кръг",
    "Adding local users and moderators" : "Добавяне на локални потребители и модератори",
    "Files" : "Файлове",
    "This feature is not available for personal circles" : "Тази функция не е налична за лични кръгове",
    "This member is not a moderator" : "Този член не е модератор",
    "Insufficient privileges" : "Недостатъчни привилегии",
    "This member does not exist" : "Този член не съществува",
    "Level cannot be changed for this type of member" : "Нивото не може да се променя за член от този тип ",
    "You are already a member of this circle" : "Вече сте член на този кръг",
    "You have been blocked from this circle" : "Бяхте блокиран от този кръг",
    "The account is already a member of this circle" : "Този профил вече е член на този кръг",
    "The account has already been invited into this circle" : "Този профил вече е бил поканен в този кръг",
    "Accept" : "Приемане",
    "Refuse" : "Отказ",
    "%s" : "%s",
    "%s owned by %s" : "%s притежаван от  %s",
    "%s shared a file with \"%s\"." : "%s сподели файл с „%s“.",
    "%s shared a file with you." : "%sсподели файл с вас. ",
    "Open %s" : "Отваряне на %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s сподели някакво съдържание с вас.\nВече трябва да сте получили отделен имейл с връзка за достъп до него.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s сподели някакво съдържание с вас.\nВече трябва да сте получили отделен имейл с връзка за достъп до него.",
    "Password to access content shared with you by %1$s" : "Парола за достъп до съдържание, споделени с вас от %1$s",
    "Password to access content" : "Парола за достъп до съдържание",
    "Bring cloud-users closer together." : "Доближете потребителите на облака по-близо.",
    "Try again" : "Опитай отново",
    "Loading…" : "Зареждане…",
    "No files in here" : "Няма файлове",
    "No entries found in this folder" : "Папката е празна",
    "Name" : "Име",
    "Size" : "Размер",
    "Modified" : "Променен на",
    "Shared to Circles" : "Споделено с Кръгове",
    "Circle" : "Кръг"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.11.tgz: nextcloud/apps/circles/l10n/bg.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Вие изтрихте {circle}",
    "{author} deleted {circle}" : "{author} изтри {circle}",
    "You removed {member} from {circle}" : "Премахнахте {member} от {circle}",
    "You joined {circle}" : "Вие се присъединихте към {circle}",
    "{member} joined {circle}" : "{member} се присъедини към {circle}",
    "You accepted the invitation to join {circle}" : "Приехте поканата да се присъедините към {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} прие поканата да се присъедини към {circle}",
    "You added {member} as member to {circle}" : "Вие добавихте {member} като член на {circle}",
    "You have been added as member to {circle} by {author}" : "Бяхте добавен като член в {circle} от {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} беше добавен като член в {circle} от {author}",
    "You added {external} to {circle}" : " Добавихте {external} към {circle}",
    "{external} has been added to {circle} by {author}" : "{external} беше добавен към {circle} от {author}",
    "You accepted {member}'s request to join {circle}" : "Приехте молбата на {member} да се присъедини към {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Заявката ви за присъединяване към {circle} беше приета от {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Заявката на {member} да се присъедини към {circle} беше приета от {author}",
    "You left {circle}" : "Вие напуснахте {circle}",
    "{member} left {circle}" : "{member} напусна {circle}",
    "You declined the invitation to join {circle}" : "Отказахте поканата да се присъедините към {circle}",
    "{member} declined an invitation to join {circle}" : "{member} отказа поканата да се присъедини към  {circle}",
    "You cancelled your request to join {circle}" : "Отменихте заявката си за присъединяване към {circle}",
    "You have been removed from {circle} by {author}" : "Бяхте премахнат от {circle} от {author}",
    "{member} has been removed from {circle} by {author}" : "{member} беше премахнат от {circle} от {author}",
    "You removed {external} from {circle}" : "Вие премахнахте {external} от {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} беше премахнат от {circle} от {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Отменихте поканата на {member} да се присъедини към {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Вашата покана за присъединяване към {circle} беше отменена от {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} отмени поканата на {member} да се присъедини към {circle}",
    "You dismissed {member}'s request to join {circle}" : "Отхвърлихте молбата на {member} за присъединяване към {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Заявката ви за присъединяване към {circle} беше отхвърлена от {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Заявката на {member} да се присъедини към {кръг} беше отхвърлена от {author}",
    "You invited {member} to join {circle}" : "Поканихте {member} да се присъедини към {circle}",
    "You have been invited to join {circle} by {author}" : " Бяхте поканен да се присъедините към {circle} от {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} беше поканен да се присъедини към {circle} от {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Променихте нивото на {member} в {circle} на %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} промени вашето ниво в {circle} на %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} промени нивото на {member} в {circle} на %1$s ",
    "You sent a request to join {circle}" : "Изпратили сте заявка за присъединяване към {circle}",
    "{member} sent a request to join {circle}" : "{member} изпрати заявка за присъединяване към {circle}",
    "You are the new owner of {circle}" : "Вие сте новият собственик на {circle}",
    "{member} is the new owner of {circle}" : "{member} е новият собственик на {circle}",
    "Single" : "Единичен",
    "Personal" : "Лични",
    "System" : "Система",
    "Visible" : "Видимо",
    "Open" : "Отвори",
    "Invite" : "Покани",
    "Friends" : "Приятели",
    "Password protected" : "Защитено с парола",
    "No Owner" : "Няма собственик",
    "Hidden" : "Скрит",
    "Backend" : " Сървър",
    "Local" : "Локален",
    "Root" : "Основен",
    "Federated" : "Федериран",
    "Mount point" : "Точка на монтиране",
    "Nextcloud Account" : "Nextcloud профил",
    "Nextcloud Group" : "Nextcloud Група",
    "Email address" : "Имейл адрес",
    "Contact" : "Контакт",
    "Team" : "Екип",
    "Nextcloud App" : "Приложение Nextcloud App",
    "Member" : "Член",
    "Moderator" : "Модератор",
    "Admin" : "Администратор",
    "Owner" : "Създател",
    "%s shared »%s« with you." : "%s сподели »%s« с вас.",
    "%s shared »%s« with \"%s\"." : "%s сподели »%s« с „%s“.",
    "%s on %s" : "%s на %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$sсподели »%2$s« с вас. Вече трябва да сте получили отделен имейл с връзка за достъп до него.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s сподели %2$s с вас. Вече трябва да сте получили отделен имейл с връзка за достъп до него.",
    "Password to access »%1$s« shared to you by %2$s" : "Парола за достъп »%1$s» е споделенас вас от %2$s",
    "Password to access »%s«" : "Парола за достъп »%s»",
    "It is protected with the following password:" : "Защитен е със следната парола:",
    "%1$s via %2$s" : "%1$sчрез %2$s ",
    "Click the button below to open it." : "Щракнете върху бутона по-долу, за да го отворите.",
    "Open »%s«" : "Отвори »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s сподели множество файла с вас. Вече трябва да сте получили отделен имейл с връзка за достъп до тях.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$sсподели множество файлове с вас. Вече трябва да сте получили отделна поща с връзка за достъп до тях. ",
    "Password to access files shared to you by %1$s" : "Парола за достъп до файлове, споделени с вас от %1$s",
    "Password to access files" : "Парола за достъп до файлове",
    "%s shared multiple files with \"%s\"." : "%s сподели множество файла с „%s“.",
    "%s shared multiple files with you." : "%sсподелени множество файлове с вас",
    "Boot up" : "Стартиране",
    "Nextcloud Initialization" : "Инициализация на Nextcloud",
    "Circles App Initialization" : "Инициализация на приложението Circles /кръгове/",
    "Fresh installation status" : "Състояние на нова инсталация",
    "Building Local Database" : "Изграждане на Локална База Данни",
    "Adding local users and moderators" : "Добавяне на локални потребители и модератори",
    "Files" : "Файлове",
    "This member is not a moderator" : "Този член не е модератор",
    "Insufficient privileges" : "Недостатъчни привилегии",
    "This member does not exist" : "Този член не съществува",
    "Level cannot be changed for this type of member" : "Нивото не може да се променя за член от този тип ",
    "Accept" : "Приемане",
    "Refuse" : "Отказ",
    "%s" : "%s",
    "%s owned by %s" : "%s притежаван от  %s",
    "%s shared a file with \"%s\"." : "%s сподели файл с „%s“.",
    "%s shared a file with you." : "%sсподели файл с вас. ",
    "Open %s" : "Отваряне на %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s сподели някакво съдържание с вас.\nВече трябва да сте получили отделен имейл с връзка за достъп до него.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s сподели някакво съдържание с вас.\nВече трябва да сте получили отделен имейл с връзка за достъп до него.",
    "Password to access content shared with you by %1$s" : "Парола за достъп до съдържание, споделени с вас от %1$s",
    "Password to access content" : "Парола за достъп до съдържание",
    "Bring cloud-users closer together." : "Доближете потребителите на облака по-близо.",
    "Try again" : "Опитай отново",
    "Loading…" : "Зареждане…",
    "No files in here" : "Няма файлове",
    "No entries found in this folder" : "Папката е празна",
    "Name" : "Име",
    "Size" : "Размер",
    "Modified" : "Променен на",
    "Shared to Circles" : "Споделено с Кръгове",
    "Testing Basic Circle Creation" : "Тестване на създаването на основен кръг",
    "This feature is not available for personal circles" : "Тази функция не е налична за лични кръгове",
    "You are already a member of this circle" : "Вече сте член на този кръг",
    "You have been blocked from this circle" : "Бяхте блокиран от този кръг",
    "The account is already a member of this circle" : "Този профил вече е член на този кръг",
    "The account has already been invited into this circle" : "Този профил вече е бил поканен в този кръг"
},
"nplurals=2; plural=(n != 1);");
